#include <stdio.h>
#include <stdbool.h>

#define MAX_KL 1000
#define C_WALL '#'
#define C_FREE '.'
#define WALL -1
#define FREE -2

#define FOR(i, from, to) for(i=(from); i<(to); i++)
#define FORDOWN(i, from, to) for(i=(from-1); i>=(to); i--)
#define AT(i, j) ( ((i)>=0 && (i)<K && (j)>=0 && (j)<L) ? map[i][j] : WALL )
#define MIN(a, b) ((a) < (b) ? (a) : (b))
#define MAX(a, b) ((a) > (b) ? (a) : (b))

int K, L; // size of whole area
int M, N; // size of the rectangle to erase
int map[MAX_KL][MAX_KL];

int N_areas = 0;

// number of fields in each area
int total[MAX_KL * MAX_KL];
int now[MAX_KL * MAX_KL]; 

int stack[MAX_KL*MAX_KL][2];
int N_stack = 0;

void stack_add(int i, int j)
{
	stack[N_stack][0] = i;
	stack[N_stack++][1] = j;
}
bool stack_pop(int *i, int *j)
{
	if(N_stack==0) return false;
	*i = stack[--N_stack][0];
	*j = stack[N_stack][1];
	return true;
}

void search(int i, int y)
{
	map[i][y] = N_areas;
	total[N_areas]++;

	if(AT(i-1, y) == FREE)
		stack_add(i-1, y);
	if(AT(i+1, y) == FREE)
		stack_add(i+1, y);
	if(AT(i, y-1) == FREE)
		stack_add(i, y-1);
	if(AT(i, y+1) == FREE)
		stack_add(i, y+1);
}

int test(int I, int J)
{
	int i, j;
	FOR(i, I-1, MIN(I+M+1, K))
		FOR(j, J-1, MIN(J+N+1, L))
		{
			if( (i==I-1 && j==J-1) || (i==I+M && j==J+N) ||
				(i==I-1 && j==J+N) || (i==I+M && j==J-1) ||
				AT(i, j)==WALL) continue;
			now[AT(i, j)]++;
		}
	int nonzero = 0;
	FOR(i, 0, N_areas)
	{
		if(now[i]>0)
			nonzero++;
		now[i] = 0;
	}

	return nonzero;
}

int main(void)
{
	int i, j;

	scanf("%d %d %d %d", &K, &L, &M, &N);

	getchar(); // newline
	FOR(i, 0, K)
	{
		FOR(j, 0, L)
		{
			char in = (getchar()==C_WALL) ? WALL : FREE;
			map[i][j] = in;
		}
		(void) getchar(); // newline
	}

	FOR(i, 0, K)
		FOR(j, 0, L)
		{
			if(AT(i, j) == FREE)
			{
				stack_add(i, j);
				int ii, jj;
				while(stack_pop(&ii, &jj))
					search(ii, jj);
				now[N_areas] = 0;
				N_areas++;
			}
		}
	// printf("N_areas = %d\n", N_areas);
	int max = 0;
	int I, J;
	
	FOR(I, 0, MAX(K-M+1, 1))
		FOR(J, 0, MAX(L-N+1, 1))
		{
			int nonzero = test(I, J);
			if(nonzero > max) 
				max = nonzero;
		}
		
	printf("%d\n", max);
	return 0;
}
